# ChangeLog

## 1.3.0
* Modify generation code of colored noise
    * numpy -> torch
    * Calculation results may differ starting with this release
    * Changed noise seed (constant -> time-based)
* Refactoring of test/test.py

## 1.2.1
* Refactoring
* Modify generation code of colored noise
    * Calculation results may differ starting with this release
* Add experimental support for numpy.typing
* Refine CI commands (modded more @ post1, post2)
* Refine pyproject.toml (modded more @ post1, post2, post3)
* Update requirements for test/
* Pin the pyenv environment (added @ post1)

## 1.2.0
* modify `vsed_debug` function

## 1.1.6.post1
* Modify readme

## 1.1.6
* Delete debug code

## 1.1.5
* Bugfix
* Modify readme
* Adjust ChangeLog

## 1.1.4.post1
* Modify readme

## 1.1.4
* Bugfix

## 1.1.3
* Bugfix (monaural only)

## 1.1.2
* Bugfix
* Process speed up↑↑

## 1.1.1
* Bugfix

## 1.1.0
* add function: trim
* add cli command: pysaten_trim

## 1.0.0.post4
* Add original of test code (MarbleNet)

## 1.0.0.post3
* Modify readme

## 1.0.0.post2
* Modify readme

## 1.0.0.post1
* Organising the commit log

## 1.0.0
* First Release
